pysyte
=======

pysyte adds batteries to

* python
* bash
* other languages near them

Badges
------

Everyone loves badges, right?

.. image:: https://badge.fury.io/py/pysyte.svg
   :target: https://pypi.python.org/pypi/pysyte
   :alt: PyPi Package

.. image:: https://travis-ci.com/jalanb/pysyte.svg?branch=__main__
   :target: https://travis-ci.com/jalanb/pysyte
   :alt: Build Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black Style

.. image:: https://codecov.io/gh/jalanb/pysyte/branch/__main__/graph/badge.svg
   :target: https://codecov.io/gh/jalanb/pysyte
   :alt: Test Coverage

.. image:: https://www.deepcode.ai/api/gh/badge?key=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJwbGF0Zm9ybTEiOiJnaCIsIm93bmVyMSI6ImphbGFuYiIsInJlcG8xIjoicHlzeXRlIiwiaW5jbHVkZUxpbnQiOmZhbHNlLCJhdXRob3JJZCI6MjAzMzYsImlhdCI6MTYyNjc5NTQ2Nn0.buSf3IC4KswMpk7tKE5tpPa0tb7QYfFAq_443cnPvtw
   :target: https://www.deepcode.ai/app/gh/jalanb/pysyte/_/dashboard
   :alt: Deep Code
